@@ -4,6 +4,7 @@
 
 ################################################################################
 # CHANGE LOG
+# 28.06.2014: Added help button and moved save gui checkbox.
 # 06.05.2014: Implemented 'checkDataset'.
 # 16.01.2014: Adding 'option' for drop-out scoring method.
 # 13.11.2013: Removed 'allele' argument in call.
@@ -19,17 +20,22 @@
 # 17.05.2013: listDataFrames() -> listObjects()
 # 09.05.2013: First version.
 
-#' @title Calculate Dropout GUI
+#' @title Calculate Dropout
 #'
 #' @description
-#' \code{calculateDropout_gui} is a GUI wrapper for the \code{calculateDropout}
-#'  function.
+#' \code{calculateDropout_gui} is a GUI wrapper for the
+#' \code{\link{calculateDropout}} function.
 #'
 #' @details Scores dropouts for a dataset.
 #' @param env environment in wich to search for data frames and save result.
 #' @param savegui logical indicating if GUI settings should be saved in the environment.
 #' @param debug logical indicating printing debug information.
 #' 
+#' @return TRUE
+#' 
+#' @export
+#' 
+#' @seealso \code{\link{calculateDropout}}, \code{\link{checkSubset}}
 
 calculateDropout_gui <- function(env=parent.frame(), savegui=NULL,
                                  debug=FALSE){
@@ -56,6 +62,22 @@ calculateDropout_gui <- function(env=parent.frame(), savegui=NULL,
                use.scrollwindow=FALSE,
                container = w,
                expand=TRUE) 
+
+  # Help button group.
+  gh <- ggroup(container = gv, expand=FALSE, fill="both")
+  
+  savegui_chk <- gcheckbox(text="Save GUI settings", checked=FALSE, container=gh)
+  
+  addSpring(gh)
+  
+  help_btn <- gbutton(text="Help", container=gh)
+  
+  addHandlerChanged(help_btn, handler = function(h, ...) {
+    
+    # Open help page for function.
+    print(help("calculateDropout_gui", help_type="html"))
+    
+  })
   
   # FRAME 0 ###################################################################
   
@@ -202,14 +224,9 @@ calculateDropout_gui <- function(env=parent.frame(), savegui=NULL,
                spacing = 5,
                container = gv) 
   
-  f1_savegui_chk <- gcheckbox(text="Save GUI settings",
-                              checked=FALSE,
-                              container=f1)
+  f1_ignore_case_chk <- gcheckbox(text="Ignore case", checked = TRUE,
+                                  container = f1)
   
-  f1_ignore_case_chk <- gcheckbox(text="Ignore case",
-                           checked = TRUE,
-                           container = f1)
-
   f1g1 <- glayout(container = f1)
   
   f1g1[1,1] <- glabel(text="Limit of detection threshold (LDT):",
@@ -340,26 +357,26 @@ calculateDropout_gui <- function(env=parent.frame(), savegui=NULL,
     
     # First check status of save flag.
     if(!is.null(savegui)){
-      svalue(f1_savegui_chk) <- savegui
-      enabled(f1_savegui_chk) <- FALSE
+      svalue(savegui_chk) <- savegui
+      enabled(savegui_chk) <- FALSE
       if(debug){
         print("Save GUI status set!")
       }  
     } else {
       # Load save flag.
       if(exists(".strvalidator_calculateDropout_gui_savegui", envir=env, inherits = FALSE)){
-        svalue(f1_savegui_chk) <- get(".strvalidator_calculateDropout_gui_savegui", envir=env)
+        svalue(savegui_chk) <- get(".strvalidator_calculateDropout_gui_savegui", envir=env)
       }
       if(debug){
         print("Save GUI status loaded!")
       }  
     }
     if(debug){
-      print(svalue(f1_savegui_chk))
+      print(svalue(savegui_chk))
     }  
     
     # Then load settings if true.
-    if(svalue(f1_savegui_chk)){
+    if(svalue(savegui_chk)){
       if(exists(".strvalidator_calculateDropout_gui_ignore", envir=env, inherits = FALSE)){
         svalue(f1_ignore_case_chk) <- get(".strvalidator_calculateDropout_gui_ignore", envir=env)
       }
@@ -386,9 +403,9 @@ calculateDropout_gui <- function(env=parent.frame(), savegui=NULL,
   .saveSettings <- function(){
     
     # Then save settings if true.
-    if(svalue(f1_savegui_chk)){
+    if(svalue(savegui_chk)){
       
-      assign(x=".strvalidator_calculateDropout_gui_savegui", value=svalue(f1_savegui_chk), envir=env)
+      assign(x=".strvalidator_calculateDropout_gui_savegui", value=svalue(savegui_chk), envir=env)
       assign(x=".strvalidator_calculateDropout_gui_ignore", value=svalue(f1_ignore_case_chk), envir=env)
       assign(x=".strvalidator_calculateDropout_gui_score1", value=svalue(f1_score1_chk), envir=env)
       assign(x=".strvalidator_calculateDropout_gui_score2", value=svalue(f1_score2_chk), envir=env)
