@@ -1,9 +1,11 @@
 ################################################################################
 # TODO LIST
 # TODO: Implemented 'checkDataset'.
+# TODO: Option to calculate sum of peak heights.
 
 ################################################################################
 # CHANGE LOG
+# 28.06.2014: Added help button and moved save gui checkbox.
 # 25.02.2014: Implemented new options 'replace NA' and 'add to dataset'.
 # 18.07.2013: Check before overwrite object.
 # 11.06.2013: Added 'inherits=FALSE' to 'exists'.
@@ -12,20 +14,24 @@
 # 20.05.2013: First version.
 
 
-#' @title Calculate H GUI
+#' @title Calculate average peak height
 #'
 #' @description
-#' \code{calculateH_gui} is a GUI wrapper for the \code{calculateH} function.
+#' \code{calculateH_gui} is a GUI wrapper for the \code{\link{calculateH}} 
+#' function.
 #'
 #' @details
-#' Simplifies the use of the \code{calculateH} function by providing a graphical 
+#' Simplifies the use of the \code{\link{calculateH}} function by providing a graphical 
 #' user interface to it.
 #' 
 #' @param env environment in wich to search for data frames and save result.
 #' @param savegui logical indicating if GUI settings should be saved in the environment.
 #' @param debug logical indicating printing debug information.
 #' 
-#' @return data.frame in slim format.
+#' @return TRUE
+#' 
+#' @export
+#' 
 #' @references
 #' Torben Tvedebrink, Poul Svante Eriksen, Helle Smidt Mogensen, Niels Morling,
 #'  Evaluating the weight of evidence by using quantitative short tandem repeat data in DNA mixtures
@@ -33,6 +39,8 @@
 #'  Volume 59, Issue 5, 2010,
 #'  Pages 855-874, 10.1111/j.1467-9876.2010.00722.x.
 #' \url{http://dx.doi.org/10.1111/j.1467-9876.2010.00722.x}
+#' 
+#' @seealso \code{\link{calculateH}}
 
 calculateH_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
   
@@ -57,6 +65,22 @@ calculateH_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
                use.scrollwindow=FALSE,
                container = w,
                expand=TRUE) 
+
+  # Help button group.
+  gh <- ggroup(container = gv, expand=FALSE, fill="both")
+  
+  savegui_chk <- gcheckbox(text="Save GUI settings", checked=FALSE, container=gh)
+  
+  addSpring(gh)
+  
+  help_btn <- gbutton(text="Help", container=gh)
+  
+  addHandlerChanged(help_btn, handler = function(h, ...) {
+    
+    # Open help page for function.
+    print(help("calculateH_gui", help_type="html"))
+    
+  })
   
   # FRAME 0 ###################################################################
   
@@ -133,10 +157,6 @@ calculateH_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
                spacing = 10,
                container = gv) 
   
-  f1_savegui_chk <- gcheckbox(text="Save GUI settings",
-                              checked=FALSE,
-                              container=f1)
-  
   f1_replace_chk <- gcheckbox(text="Replace NA with 0",
                               checked=TRUE,
                               container=f1)
@@ -210,26 +230,26 @@ calculateH_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
     
     # First check status of save flag.
     if(!is.null(savegui)){
-      svalue(f1_savegui_chk) <- savegui
-      enabled(f1_savegui_chk) <- FALSE
+      svalue(savegui_chk) <- savegui
+      enabled(savegui_chk) <- FALSE
       if(debug){
         print("Save GUI status set!")
       }  
     } else {
       # Load save flag.
       if(exists(".strvalidator_calculateH_gui_savegui", envir=env, inherits = FALSE)){
-        svalue(f1_savegui_chk) <- get(".strvalidator_calculateH_gui_savegui", envir=env)
+        svalue(savegui_chk) <- get(".strvalidator_calculateH_gui_savegui", envir=env)
       }
       if(debug){
         print("Save GUI status loaded!")
       }  
     }
     if(debug){
-      print(svalue(f1_savegui_chk))
+      print(svalue(savegui_chk))
     }  
     
     # Then load settings if true.
-    if(svalue(f1_savegui_chk)){
+    if(svalue(savegui_chk)){
       if(exists(".strvalidator_calculateH_gui_replace", envir=env, inherits = FALSE)){
         svalue(f1_replace_chk) <- get(".strvalidator_calculateH_gui_replace", envir=env)
       }
@@ -246,9 +266,9 @@ calculateH_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
   .saveSettings <- function(){
     
     # Then save settings if true.
-    if(svalue(f1_savegui_chk)){
+    if(svalue(savegui_chk)){
       
-      assign(x=".strvalidator_calculateH_gui_savegui", value=svalue(f1_savegui_chk), envir=env)
+      assign(x=".strvalidator_calculateH_gui_savegui", value=svalue(savegui_chk), envir=env)
       assign(x=".strvalidator_calculateH_gui_replace", value=svalue(f1_replace_chk), envir=env)
       assign(x=".strvalidator_calculateH_gui_add", value=svalue(f1_add_chk), envir=env)
       
