@@ -4,6 +4,7 @@
 
 ################################################################################
 # CHANGE LOG
+# 28.06.2014: Added help button and moved save gui checkbox.
 # 06.01.2014: Fixed button name used as 'save as' name.
 # 20.11.2013: Fixed result now stored in variable 'datanew' insted of 'val_name'.
 # 29.09.2013: First version.
@@ -12,8 +13,8 @@
 #' @title Bins Overlap
 #'
 #' @description
-#' \code{calculateOverlap_gui} is a GUI wrapper for the \code{calculateOverlap}
-#'  function.
+#' \code{calculateOverlap_gui} is a GUI wrapper for the
+#' \code{\link{calculateOverlap}} function.
 #'
 #' @details By analysis of the bins overlap between dye channels a measure of
 #' the risk for spectral pull-up artefacts can be obtain. The default result
@@ -28,6 +29,12 @@
 #' @param env environment in wich to search for data frames and save result.
 #' @param savegui logical indicating if GUI settings should be saved in the environment.
 #' @param debug logical indicating printing debug information.
+#' 
+#' @return TRUE
+#' 
+#' @export
+#' 
+#' @seealso \code{\link{calculateOverlap}}
 
 calculateOverlap_gui <- function(env=parent.frame(), savegui=NULL, debug=TRUE){
   
@@ -48,6 +55,22 @@ calculateOverlap_gui <- function(env=parent.frame(), savegui=NULL, debug=TRUE){
                use.scrollwindow=FALSE,
                container = w,
                expand=TRUE) 
+
+  # Help button group.
+  gh <- ggroup(container = gv, expand=FALSE, fill="both")
+  
+  savegui_chk <- gcheckbox(text="Save GUI settings", checked=FALSE, container=gh)
+  
+  addSpring(gh)
+  
+  help_btn <- gbutton(text="Help", container=gh)
+  
+  addHandlerChanged(help_btn, handler = function(h, ...) {
+    
+    # Open help page for function.
+    print(help("calculateOverlap_gui", help_type="html"))
+    
+  })
   
   # FRAME 0 ###################################################################
   
@@ -172,10 +195,6 @@ calculateOverlap_gui <- function(env=parent.frame(), savegui=NULL, debug=TRUE){
                spacing = 5,
                container = gv) 
   
-  f1_savegui_chk <- gcheckbox(text="Save GUI settings",
-                              checked=FALSE,
-                              container=f1)
-  
   f1_db_chk <- gcheckbox(text="Multiply overlap with allele frequency",
                          checked=TRUE,
                          container=f1)
@@ -184,15 +203,6 @@ calculateOverlap_gui <- function(env=parent.frame(), savegui=NULL, debug=TRUE){
   
   f1_db_drp <- gdroplist(items=f1_db_names, fill=FALSE, selected = 1, container=f1)
 
-  addHandlerChanged(f1_db_chk, handler = function(h, ...) {
-    val_chk <- svalue(f1_db_chk)
-    if(val_chk){
-      enabled(f1_db_drp) <- TRUE
-    } else {
-      enabled(f1_db_drp) <- FALSE
-    }
-  })
-  
   f1_virtual_chk <- gcheckbox(text="Include virtual bins in analysis",
                               checked=TRUE,
                               container=f1)
@@ -207,6 +217,17 @@ calculateOverlap_gui <- function(env=parent.frame(), savegui=NULL, debug=TRUE){
                             checked=TRUE,
                             container=f1)
   
+  # HANDLERS ------------------------------------------------------------------
+  
+  addHandlerChanged(f1_db_chk, handler = function(h, ...) {
+    val_chk <- svalue(f1_db_chk)
+    if(val_chk){
+      enabled(f1_db_drp) <- TRUE
+    } else {
+      enabled(f1_db_drp) <- FALSE
+    }
+  })
+  
   addHandlerChanged(f1_penalty_chk, handler = function(h, ...) {
     val_chk <- svalue(f1_penalty_chk)
     if(val_chk){
@@ -371,26 +392,26 @@ calculateOverlap_gui <- function(env=parent.frame(), savegui=NULL, debug=TRUE){
     
     # First check status of save flag.
     if(!is.null(savegui)){
-      svalue(f1_savegui_chk) <- savegui
-      enabled(f1_savegui_chk) <- FALSE
+      svalue(savegui_chk) <- savegui
+      enabled(savegui_chk) <- FALSE
       if(debug){
         print("Save GUI status set!")
       }  
     } else {
       # Load save flag.
       if(exists(".strvalidator_calculateOverlap_gui_savegui", envir=env, inherits = FALSE)){
-        svalue(f1_savegui_chk) <- get(".strvalidator_calculateOverlap_gui_savegui", envir=env)
+        svalue(savegui_chk) <- get(".strvalidator_calculateOverlap_gui_savegui", envir=env)
       }
       if(debug){
         print("Save GUI status loaded!")
       }  
     }
     if(debug){
-      print(svalue(f1_savegui_chk))
+      print(svalue(savegui_chk))
     }  
     
     # Then load settings if true.
-    if(svalue(f1_savegui_chk)){
+    if(svalue(savegui_chk)){
       if(exists(".strvalidator_calculateOverlap_gui_db", envir=env, inherits = FALSE)){
         svalue(f1_db_chk) <- get(".strvalidator_calculateOverlap_gui_db", envir=env)
       }
@@ -429,9 +450,9 @@ calculateOverlap_gui <- function(env=parent.frame(), savegui=NULL, debug=TRUE){
   .saveSettings <- function(){
     
     # Then save settings if true.
-    if(svalue(f1_savegui_chk)){
+    if(svalue(savegui_chk)){
       
-      assign(x=".strvalidator_calculateOverlap_gui_savegui", value=svalue(f1_savegui_chk), envir=env)
+      assign(x=".strvalidator_calculateOverlap_gui_savegui", value=svalue(savegui_chk), envir=env)
       assign(x=".strvalidator_calculateOverlap_gui_db", value=svalue(f1_db_chk), envir=env)
       assign(x=".strvalidator_calculateOverlap_gui_db_name", value=svalue(f1_db_drp), envir=env)
       assign(x=".strvalidator_calculateOverlap_gui_virtual", value=svalue(f1_virtual_chk), envir=env)
