@@ -4,6 +4,7 @@
 
 ################################################################################
 # CHANGE LOG
+# 28.06.2014: Added help button and moved save gui checkbox.
 # 08.05.2014: Implemented 'checkDataset'.
 # 06.02.2014: Fixed button locks when error.
 # 06.02.2014: Changed name calculatePrecision_gui -> tablePrecision_gui
@@ -13,19 +14,20 @@
 #' @title Calculate Precision
 #'
 #' @description
-#' \code{tablePrecision_gui} is a GUI wrapper for the \code{calculatePrecision}
+#' \code{tablePrecision_gui} is a GUI wrapper for the \code{\link{tablePrecision}}
 #'  function.
 #'
 #' @details
-#' Simplifies the use of the \code{calculatePrecision} function by providing 
+#' Simplifies the use of the \code{\link{tablePrecision}} function by providing 
 #' a graphical user interface.
 #' 
 #' @param env environment in wich to search for data frames and save result.
 #' @param savegui logical indicating if GUI settings should be saved in the environment.
 #' @param debug logical indicating printing debug information.
 #' 
-#' @return data.frame
+#' @return TRUE
 #' 
+#' @seealso \code{\link{tablePrecision}}, \code{\link{checkSubset}}
 
 tablePrecision_gui <- function(env=parent.frame(), savegui=NULL,
                                  debug=FALSE){
@@ -57,6 +59,22 @@ tablePrecision_gui <- function(env=parent.frame(), savegui=NULL,
                use.scrollwindow=FALSE,
                container = w,
                expand=TRUE) 
+
+  # Help button group.
+  gh <- ggroup(container = gv, expand=FALSE, fill="both")
+  
+  savegui_chk <- gcheckbox(text="Save GUI settings", checked=FALSE, container=gh)
+  
+  addSpring(gh)
+  
+  help_btn <- gbutton(text="Help", container=gh)
+  
+  addHandlerChanged(help_btn, handler = function(h, ...) {
+    
+    # Open help page for function.
+    print(help("tablePrecision_gui", help_type="html"))
+    
+  })
   
   # FRAME 0 ###################################################################
   
@@ -304,10 +322,6 @@ tablePrecision_gui <- function(env=parent.frame(), savegui=NULL,
                expand=TRUE,
                container = gv) 
   
-  f1_savegui_chk <- gcheckbox(text="Save GUI settings",
-                              checked=FALSE,
-                              container=f1)
-  
   f1_ignore_chk <- gcheckbox(text="Ignore case",
                              checked=TRUE,
                              container=f1)
@@ -594,26 +608,26 @@ tablePrecision_gui <- function(env=parent.frame(), savegui=NULL,
     
     # First check status of save flag.
     if(!is.null(savegui)){
-      svalue(f1_savegui_chk) <- savegui
-      enabled(f1_savegui_chk) <- FALSE
+      svalue(savegui_chk) <- savegui
+      enabled(savegui_chk) <- FALSE
       if(debug){
         print("Save GUI status set!")
       }  
     } else {
       # Load save flag.
       if(exists(".strvalidator_tablePrecision_gui_savegui", envir=env, inherits = FALSE)){
-        svalue(f1_savegui_chk) <- get(".strvalidator_tablePrecision_gui_savegui", envir=env)
+        svalue(savegui_chk) <- get(".strvalidator_tablePrecision_gui_savegui", envir=env)
       }
       if(debug){
         print("Save GUI status loaded!")
       }  
     }
     if(debug){
-      print(svalue(f1_savegui_chk))
+      print(svalue(savegui_chk))
     }  
         
     # Then load settings if true.
-    if(svalue(f1_savegui_chk)){
+    if(svalue(savegui_chk)){
       if(exists(".strvalidator_tablePrecision_gui_filter", envir=env, inherits = FALSE)){
         svalue(f2_filter_opt) <- get(".strvalidator_tablePrecision_gui_filter", envir=env)
       }
@@ -633,9 +647,9 @@ tablePrecision_gui <- function(env=parent.frame(), savegui=NULL,
   .saveSettings <- function(){
     
     # Then save settings if true.
-    if(svalue(f1_savegui_chk)){
+    if(svalue(savegui_chk)){
       
-      assign(x=".strvalidator_tablePrecision_gui_savegui", value=svalue(f1_savegui_chk), envir=env)
+      assign(x=".strvalidator_tablePrecision_gui_savegui", value=svalue(savegui_chk), envir=env)
       assign(x=".strvalidator_tablePrecision_gui_filter", value=svalue(f2_filter_opt), envir=env)
       assign(x=".strvalidator_tablePrecision_gui_ignore", value=svalue(f1_ignore_chk), envir=env)
       assign(x=".strvalidator_tablePrecision_gui_exclude", value=svalue(f2g2_virtual_chk), envir=env)
